@@ -1,6 +1,6 @@
 import click
 
-from sdo.cmd.goes import cmd_download
+from sdo.cmd.goes import cmd_download, cmd_get
 
 
 @click.group("goes")
@@ -9,3 +9,4 @@ def cli():
 
 
 cli.add_command(cmd_download.download)
+cli.add_command(cmd_get.get)
